pub struct TypedIntoMessageSavingHandler<T> { /* private fields */ }Expand description
Ownership-based typed handler which saves the messages it receives.
Unlike TypedMessageSavingHandler which borrows messages, this handler
takes ownership which is required for IntoEndpointMap endpoints.
Implementations
Sourceimpl<T: 'static> TypedIntoMessageSavingHandler<T>
impl<T: 'static> TypedIntoMessageSavingHandler<T>
pub fn new(id: Option<Ustr>) -> Self
Sourcepub fn new_with_messages(
id: Option<Ustr>,
messages: Rc<RefCell<Vec<T>>>,
) -> Self
pub fn new_with_messages( id: Option<Ustr>, messages: Rc<RefCell<Vec<T>>>, ) -> Self
Creates a handler backed by an existing shared messages vec.
pub fn get_messages(&self) -> Vec<T>where
T: Clone,
Sourcepub fn handler(&self) -> TypedIntoHandler<T>
pub fn handler(&self) -> TypedIntoHandler<T>
Returns a TypedIntoHandler that can be used for endpoint registration.
pub fn clear(&self)